@@ -1,7 +1,7 @@
 package PERLANCAR::Permute::Named;
 
-our $DATE = '2015-10-02'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-09-25'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -57,7 +57,7 @@ PERLANCAR::Permute::Named - Permute multiple-valued key-value pairs
 
 =head1 VERSION
 
-This document describes version 0.02 of PERLANCAR::Permute::Named (from Perl distribution PERLANCAR-Permute-Named), released on 2015-10-02.
+This document describes version 0.03 of PERLANCAR::Permute::Named (from Perl distribution PERLANCAR-Permute-Named), released on 2016-09-25.
 
 =head1 SYNOPSIS
 
@@ -110,12 +110,6 @@ just returns the one permutation:
 
  {bool => 1, x => 'foo'}
 
-=head1 SEE ALSO
-
-L<Permute::Named>
-
-L<Permute::Named::Iter>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/PERLANCAR-Permute-Named>.
@@ -132,13 +126,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Permute::Named>, L<Permute::Named::Iter> and CLI <permute-named>
+
+L<Set::CrossProduct> and L<cross>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
